@@ -13,9 +13,9 @@
 #' @return A \code{ggplot} object.
 #' @export
 #' @examples
-#' data(samples)
-#' ggs_caterpillar(ggs(S))
-#' ggs_caterpillar(list(A=ggs(S), B=ggs(S))) # silly example duplicating the same model
+#' data(linear)
+#' ggs_caterpillar(ggs(s))
+#' ggs_caterpillar(list(A=ggs(s), B=ggs(s))) # silly example duplicating the same model
 ggs_caterpillar <- function(D, family=NA, X=NA, 
   thick_ci=c(0.05, 0.95), thin_ci=c(0.025, 0.975),
   line=NA, horizontal=TRUE, model_labels=NULL) {
@@ -47,39 +47,25 @@ ggs_caterpillar <- function(D, family=NA, X=NA,
   # http://stackoverflow.com/questions/6955128/object-not-found-error-with-ddply-inside-a-function
   # One of the solutions, not elegant, is to assign qs globally (as well as
   # locally  for further commands in this function
-  qs  <- qs <<- c(thin.low=thin_ci[1], thick.low=thick_ci[1], 
-                  median=0.5, thick.high=thick_ci[2], thin.high=thin_ci[2])
-  
+ 
   # Multiple models or a single model
-  #
   if (!is.data.frame(D)) { # D is a list, and so multiple models are passed
     multi <- TRUE # used later in plot call
+    dcm <- NULL
     for (i in 1:length(D)) { # iterate over list elements
-      dc <- ddply(D[[i]], .(Parameter), summarize,
-                  q=quantile(value, probs=qs), qs=qs)
-      dc$qs <- factor(dc$qs, labels=names(qs))
-      dcm <- dcast(dc, Parameter ~ qs, value.var="q")
-      D[[i]] <- dcm # replace list element with transformed list element
+      # Get model labels, by default the description attribute of the ggs object
+      model.label <- attributes(D[[i]]$description)[i]
+      # But prevalence is for the names of the named list, not for labels or for the description
+      if (length(model_labels)==length(D)) model.label <- model_labels[i]  # get model labels from labels
+      if (length(names(D)!=0)) model.label <- names(D)[i]                   # get model labels from named list
+
+      # Transform list elements into wide dfs with thick and thin limits
+      dcm <- rbind_list(dcm, ci(D[[i]]) %>% mutate(Model=model.label))
     }
-    #
-    # Get model names, by default the description attribute of the ggs object
-    model.names <- lapply(D, function(x) return(attributes(x)$description))
-    # But prevalence is for the names of the named list, not for labels or for the description
-    if (length(model_labels)==length(D)) model.names <- model_labels       # get model names from labels
-    if (length(names(D)!=0)) model.names <- names(D)           # get model names from named list
-    # Final data frame to use for plotting
-    dcm <- do.call(
-      rbind, 
-      lapply(1:length(D), 
-        function(i) if (length(D[[i]]) > 1) cbind(D[[i]], Model=model.names[i])))
 
   } else if (is.data.frame(D)) { # D is a data frame, and so a single model is passed
     multi <-  FALSE
-    dc <- ddply(D, .(Parameter), summarize, 
-                q=quantile(value, probs=qs), qs=qs,
-                .parallel=attributes(D)$parallel)
-    dc$qs <- factor(dc$qs, labels=names(qs))
-    dcm <- dcast(dc, Parameter ~ qs, value.var="q")
+    dcm <- ci(D)
   }
 
   #
@@ -87,14 +73,14 @@ ggs_caterpillar <- function(D, family=NA, X=NA,
   #
   if (!x.present) {
     f <- ggplot(dcm, aes(x=median, y=reorder(Parameter, median))) + geom_point(size=3) +
-      geom_segment(aes(x=thick.low, xend=thick.high, yend=reorder(Parameter, median)), size=1.5) +
-      geom_segment(aes(x=thin.low, xend=thin.high, yend=reorder(Parameter, median)), size=0.5) +
+      geom_segment(aes(x=Low, xend=High, yend=reorder(Parameter, median)), size=1.5) +
+      geom_segment(aes(x=low, xend=high, yend=reorder(Parameter, median)), size=0.5) +
       xlab("HPD") + ylab("Parameter")
   } else {
     dcm <- merge(dcm, X)
     f <- ggplot(dcm, aes_string(x="median", y=x.name)) + geom_point(size=3) +
-      geom_segment(aes_string(x="thick.low", xend="thick.high", yend=x.name), size=1.5) +
-      geom_segment(aes_string(x="thin.low", xend="thin.high", yend=x.name), size=0.5) +
+      geom_segment(aes_string(x="Low", xend="High", yend=x.name), size=1.5) +
+      geom_segment(aes_string(x="low", xend="high", yend=x.name), size=0.5) +
       xlab("HPD") + ylab(x.name)
   }
 
