@@ -9,8 +9,8 @@
 #' @return A \code{ggplot} object.
 #' @export
 #' @examples
-#' data(samples)
-#' ggs_compare_partial(ggs(S))
+#' data(linear)
+#' ggs_compare_partial(ggs(s))
 ggs_compare_partial <- function(D, family=NA, partial=0.1, rug=FALSE) {
   # Check that partial is a percentage
   if (partial <= 0 | partial >=1 | !is.numeric(partial)) {
@@ -24,10 +24,9 @@ ggs_compare_partial <- function(D, family=NA, partial=0.1, rug=FALSE) {
   n.samples <- max(D$Iteration)
   # Add more rows to the original dataframe according to the desired size of the
   # comparison
-  D.comp <- rbind(
-    cbind(part_chain="Complete", D), 
-    cbind(part_chain="Partial", 
-      subset(D, Iteration>(n.samples-trunc(n.samples * partial)))))
+  D.comp <- rbind_list(
+    mutate(D, part_chain="Complete"),
+    mutate(filter(D, Iteration > (n.samples-trunc(n.samples * partial))), part_chain="Partial"))
 
   # Generate the plot
   f <- ggplot(D.comp, aes(x=value, fill=part_chain, colour=part_chain), group=Chain) + 
