@@ -8,21 +8,21 @@
 #' @return A \code{ggplot} object.
 #' @export
 #' @examples
-#' data(samples)
-#' ggs_histogram(ggs(S))
+#' data(linear)
+#' ggs_histogram(ggs(s))
 ggs_histogram <- function(D, family=NA, bins=30) {
   # Manage subsetting a family of parameters
   if (!is.na(family)) {
     D <- get_family(D, family=family)
   }
-  # Manually generate the histogram by parameter, based on the total number of
-  # bins
-  l <- unlist(dlply(D, .(Parameter), here(summarize), calc.bin(value, bins)), recursive=FALSE)
-  ds <- ldply(l, data.frame)
-  dl <- as.numeric(table(ds$`.id`))
+  # Manually generate the histogram by parameter, based on the total number of bins
+  ds <- D %>%
+    group_by(Parameter) %>%
+    do(calc_bin(.$value, bins))
+  dl <- as.numeric(table(ds$Parameter))
   # There may be cases of parameters with slightly different numbers of bins,
   # and therefore a Parameter-by-Parameter approach is needed
-  ds <- cbind(Parameter=gl.unq(attributes(D)$nParameters, dl, labels=levels(D$Parameter)), ds)
+  ds <- cbind(Parameter=gl_unq(attributes(D)$nParameters, dl, labels=levels(D$Parameter)), ds)
   # Plot
   f <- ggplot(ds, aes(x=x, y=count, width=width)) + geom_bar(stat="identity", position="identity") +
     facet_wrap(~ Parameter, ncol=1, scales="free") + xlab("value")
